#!/umr/bin/perl

# Written by:	K.N. Swamy and Neil Phipps
# Last updated: 5/14/01
# Description:	This script allows a teacher to enter questions into 
#		the question pool and allows a teacher to modify one
#		of his/her own questions that exist in the question 
#		pool.  This includes the use of a picture pool.
# Inputs:	This file takes various user inputs.  Other than the
#		input of question material, it will require the
#		user_id from the cookie to verify the teacher and 
#		it will require a question number from the question
#		pool if the teacher is planning on modifying a
#		question.
# Outputs:	This file outputs the question and picture
#		information to the database.  It will return a
#		unique picture number if a new question is being
#		created.

#used for database
use lib "/afs/umr.edu/software/umrperl/libs";
use UMR::OracleObject;
use UMR::HTMLUtil;

# Call script to get subroutines that are common to all scripts.
require "geometry_funcs.pl";

# Initialize %rqpairs with submitted variables
&HTMLGetRequest;

# Check variable "mode" to decide what the script should do
$mode=$rqpairs{"mode"};




#---------------------------------------------------------
# User chooses to create or modify a question here.
#---------------------------------------------------------

unless ($mode)
{
 # Get credentials from the cookie.
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 $oradb = new UMR::OracleObject;
 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 # Verify the credentials and that the user is a teacher.
 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }

 
 # Set-up HTML document.
 &HTMLContentType;
 $title="Create Test Question";
 display_HTML_header($title);
 
 &HTMLStartForm(&HTMLScriptURL);

 print "<BR> <H3>Please choose an option and click submit. </H3><BR>\n";

 # Give the options for usaer to choose.
 &HTMLRadioButton("mode","modify_question",1);
 print "Modify A Test Question <BR>\n";
 &HTMLRadioButton("mode","input_test",0);
 print "Create A Test Question <BR>\n";
 
 print "<BR>";
 &HTMLSubmit("Submit"); 

 # End the HTML form.
 &HTMLEndForm;
 print "\n";
 
 display_HTML_footer();
 
}


#---------------------------------------------------------
# User chooses to create a question, go to this subroutine
# for question input.
#---------------------------------------------------------

if ($mode eq "input_test")
{
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 $oradb = new UMR::OracleObject;
 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }
 
 
 # Set-up HTML document.
 &HTMLContentType;
 $title="Change Customer Data";
 display_HTML_header($title);
 
 &HTMLStartForm(&HTMLScriptURL);

	# Receive all passed data.  This is passed to this routine when
	# the user returns from the picture pool.
	print "\n";
	$picture1 = $rqpairs{"picture1"};
	$picture2 = $rqpairs{"picture2"};
	$question = $rqpairs{"question"};
	$answer1 = $rqpairs{"answer1"};
	$answer2 = $rqpairs{"answer2"};
	$answer3 = $rqpairs{"answer3"};
	$answer4 = $rqpairs{"answer4"};
	$subject = $rqpairs{"subject"};

	&HTMLHidden("mode","run_input_test");

	# Display all text boxes to input test question.
	print "<br>\n";
	print "Input the Test Question";
	print "<br>\n";
	&HTMLTextArea("question",$question,60,10);
	print "<br>";
	
	print "Picture 1 Number: ";
	&HTMLInputText("picture1",5,$picture1);
	# Button to go to picture pool.
	print " &nbsp;&nbsp;&nbsp;&nbsp;
	  <input type=\"submit\" name=\"test\" value=\"Get Picture 1\">";
	print "<br>\n";
	print "Picture 2 Number: ";
	&HTMLInputText("picture2",5,$picture2);
	# Button to go to picture pool.
	print " &nbsp;&nbsp;&nbsp;&nbsp;
	  <input type=\"submit\" name=\"test\" value=\"Get Picture 2\">";
	print "<BR>\n";

	#choice button allows the user to choose the correct 
	#answer from all the four possible answers

	print "<br>\n";
	print "Input possible answers and choose the button before the correct answer.";
	print "<br>\n";

	&HTMLRadioButton("choice","A",$on," Answer 1 ");	
	&HTMLInputText("answer1",50,$answer1);
	print "<br>\n";
	&HTMLRadioButton("choice","B",$off," Answer 2 ");
	&HTMLInputText("answer2",50,$answer2);
	print "<br>\n";
	&HTMLRadioButton("choice","C",$off," Answer 3 ");
	&HTMLInputText("answer3",50,$answer3);
	print "<br>\n";
	&HTMLRadioButton("choice","D",$off," Answer 4 ");
	&HTMLInputText("answer4",50,$answer4);
	print "<br>\n";

	# The subject tag is needed to pull out questions from
	# the question pool later on

	print "<br>\n";
	print "Choose the subject this question applies to.";
	print "<br>\n";
	&HTMLRadioButton("subject","AREA AND VOLUME",1,"  The Area and Volume Test");
	print "<BR>\n";
	&HTMLRadioButton("subject","POLYGONS AND THEIR MEASUREMENTS",0,"  The Polygons and Their Measurements Test");
	print "<BR>\n";
	&HTMLRadioButton("subject","TRIG FUNCTIONS",0,"  The Trig Functions Test");
	
	
	print "<BR><BR>\n";
	print "<input type=\"submit\" name=\"test\" value=\"Submit Question\">";
	print "<br>\n";


 # End the HTML form.
 &HTMLEndForm;
 print "\n";
 
 display_HTML_footer();
}




#---------------------------------------------------------
# This script does the actual insertion of the question into
# the question pool in the database if that option is chosen.
# Otherwise it displays a list of pictures to be selected
# for the question
#---------------------------------------------------------
if ($mode eq "run_input_test")
{
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 
 $oradb = new UMR::OracleObject;

 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }


 # Set-up HTML document.
 &HTMLContentType;
 $title="Create Test Question";
 display_HTML_header($title);
 

	$username = $oradb->SQL_QuoteString($username);
	$picture1 = $rqpairs{"picture1"};
	$picture2 = $rqpairs{"picture2"};
	$questno = $rqpairs{"questno"};
	$question = $rqpairs{"question"};
	$answer1 = $rqpairs{"answer1"};
	$answer2 = $rqpairs{"answer2"};
	$answer3 = $rqpairs{"answer3"};
	$answer4 = $rqpairs{"answer4"};
	$subject = $rqpairs{"subject"};
	$choice = $rqpairs{"choice"};
	$test_choice = $rqpairs{"test"};
 
	$sqlerror = "<H2> Your submission has an error. Please be sure that all 
		fields were filled in on the previous page and one question was selected
		as the correct answer. </H2><BR>\n";

	# Get a unique question number
	$qry = "SELECT Q_NO from Question_Pool ORDER BY Q_NO";
	$cid=$oradb->SQL_OpenQuery($qry) or die "$sqlerror";

	while ( @a_row = $oradb->SQL_FetchRow($cid) )
 	{
   		$number = $a_row[0];
   	}
	$questno=$number+1;

 	$oradb->SQL_CloseQuery($cid);	
	
	
	
	# Submit the question to the database.
	if ($test_choice eq "Submit Question") 
	{
  	$qry="insert into QUESTION_POOL(Q_NO,QUESTION,ANSWER_1,ANSWER_2,ANSWER_3".
 	",ANSWER_4,CORRECT_NUMBER,OWNER,SUBJECT) values (".
 	"$questno,\'$rqpairs{\"question\"}\',\'$rqpairs{\"answer1\"}\'".
 	",\'$rqpairs{\"answer2\"}\',\'$rqpairs{\"answer3\"}\',\'$rqpairs{\"answer4\"}\'".
 	",\'$rqpairs{\"choice\"}\',$username,\'$rqpairs{\"subject\"}\')";

 	#print "Sent query \"$qry\" to database<BR>\n";

	$cid=$oradb->SQL_OpenQuery($qry) or die "$sqlerror";
 	#$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

 
 	$oradb->SQL_CloseQuery($cid);

	# Insert pictures into the picture_used relation to associate a picture 
	# with a test question.
 	unless ($picture1 eq "") {
	$qry="insert into PICTURE_USED(PICTURE_NUMBER,Q_NO) values (".
	"\'$picture1\',\'$questno\')";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";
 	$oradb->SQL_CloseQuery($cid);
	}
	unless ($picture2 eq "") {
	$qry="insert into PICTURE_USED(PICTURE_NUMBER,Q_NO) values (".
	"\'$picture2\',\'$questno\')";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";
 	$oradb->SQL_CloseQuery($cid);
	
	}
	&HTMLStartForm(&HTMLScriptURL);
 	print "\n";
	
	print "Your question was inserted as question number: $questno <BR><BR>
	       Please keep this number for your records. <BR> You will need this number if you
	       later wish to edit this question. <BR><BR>";
 	
 	&HTMLSubmit("<-Back");
 	print "\n";
	&HTMLEndForm;
 	print "\n";
	} 

	# View Picture Pool
	elsif ($test_choice eq "Get Picture 1")
	{
	&HTMLStartForm(&HTMLScriptURL);
	print "\n";
	$qry="SELECT * From PICTURE order by picture_number";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

 		#print "Sent query \"$qry\" to database<BR>\n";
		
		print "<H4>Select the radio button to the picture you would like to appear
			in your test and select the return button at the bottom of the 
			page.</H4><BR><BR>";
		
		while ( @a_row = $oradb->SQL_FetchRow($cid) )
 		{
		&HTMLRadioButton("picture1",$a_row[0],$off,"Picture Number: $a_row[0]");
		
		##------------------------------------------------------------------
		## To change the location of the picture pool, adjust this path.
		##------------------------------------------------------------------
		print "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
		print "<IMG SRC=http://www.umr.edu/~traxdev/pics/$a_row[1]>";
		#print "<IMG SRC=http://www.umr.edu/~traxdev/pics/$a_row[1] WIDTH=200
		#HEIGHT=200 border=0>";
		print "<BR><BR><BR>\n";
		}
		# Variables to pass back.
		&HTMLHidden("mode","input_test");
		print "\n";
		&HTMLHidden("question",$question);
		&HTMLHidden("answer1",$answer1);
		&HTMLHidden("answer2",$answer2);
		&HTMLHidden("answer3",$answer3);
		&HTMLHidden("answer4",$answer4);
		&HTMLHidden("subject",$subject);
		&HTMLHidden("picture2",$picture2);
		&HTMLHidden("choice",$choice);
		print "<BR>\n";
		print "<BR>\n";
		print "<BR>\n";						
		&HTMLSubmit("Select and Return");
 		print "\n";
		&HTMLEndForm;
 		print "\n";
	}
	
	# View Picture Pool
	elsif ($test_choice eq "Get Picture 2")
	{
	&HTMLStartForm(&HTMLScriptURL);
	print "\n";
	$qry="SELECT * From PICTURE order by picture_number";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

		print "<H4>Select the radio button to the picture you would like to appear
			in your test and click the return button at the bottom of the 
			page.</H4><BR><BR>";

 	#print "Sent query \"$qry\" to database<BR>\n";
	while ( @a_row = $oradb->SQL_FetchRow($cid) )
 	{
		&HTMLRadioButton("picture2",$a_row[0],$off,"Picture Number: $a_row[0]");

		##------------------------------------------------------------------
		## To change the location of the picture pool, adjust this path.
		##------------------------------------------------------------------
		print "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
		print "<IMG SRC=http://www.umr.edu/~traxdev/pics/$a_row[1]>";
		print "<BR><BR><BR>\n";
	}
		# Variables to pass back.
		&HTMLHidden("mode","input_test");
		print "\n";
		&HTMLHidden("question",$question);
		&HTMLHidden("answer1",$answer1);
		&HTMLHidden("answer2",$answer2);
		&HTMLHidden("answer3",$answer3);
		&HTMLHidden("answer4",$answer4);
		&HTMLHidden("subject",$subject);
		&HTMLHidden("picture1",$picture1);
		&HTMLHidden("choice",$choice);
		print "<BR>\n";
		print "<BR>\n";
		print "<BR>\n";						
		&HTMLSubmit("Select and Return");
 		print "\n";
		&HTMLEndForm;
 		print "\n";
 		}

 # End the HTML form.
 display_HTML_footer();	

 }



#---------------------------------------------------------
# User chooses to modify a question, go to this subroutine
# for input of the question number to modify.
#---------------------------------------------------------

if ($mode eq "modify_question")
{
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 
 $oradb = new UMR::OracleObject;

 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }

 # Set-up HTML document.
 &HTMLContentType;
 $title="Modify Test Question";
 display_HTML_header($title);
 
 &HTMLStartForm(&HTMLScriptURL);

 # Set the mode so that "Submit" will go to the next subroutine.
 print "\n";
 &HTMLHidden("mode","display_modify");

 # Place input boxes, submit button, and other text in browser window.
 print "<BR>";
 print "Give the Question Number to be modified: ";
 &HTMLInputText("questno",9,"");
 print "<BR>";
 &HTMLSubmit("Submit");
 
 $sqlerror = "Your questions cannot be retrieved from the database at this time.";

 $username = $oradb->SQL_QuoteString($username);
 
 print "<BR><BR><H4>A list of your questions with question number.</H4>";
 
 # Give the user a list of their test questions.
 $qry="SELECT Q_NO, QUESTION from QUESTION_POOL where owner = $username";
 #print "Sent query \"$qry\" to database<BR>\n";
 $cid=$oradb->SQL_OpenQuery($qry) or die "$sqlerror";

 while ( @a_row = $oradb->SQL_FetchRow($cid) )
 {
   print "<BR>$a_row[0] . &nbsp; $a_row[1] <BR>";
 }
 
 $oradb->SQL_CloseQuery($cid);

 # End the HTML form.
 &HTMLEndForm;
 print "\n";
 
 display_HTML_footer();
}


#---------------------------------------------------------
# User chooses to modify a question, go to this subroutine
# for question input.  This display is based on the number
# input in the previous routine.  The fields are filled
# based on what the database currently has for the question.
#---------------------------------------------------------

if ($mode eq "display_modify") 
{
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 
 $oradb = new UMR::OracleObject;

 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }

 
 # Set-up HTML document.
 &HTMLContentType;
 $title="Change Customer Data";
 display_HTML_header($title);
 
 &HTMLStartForm(&HTMLScriptURL);

	print "\n";
	$questno = $rqpairs{"questno"};
	$quoted_questno = $oradb->SQL_QuoteString($questno);
	$picture1 = $rqpairs{"picture1"};
	$picture2 = $rqpairs{"picture2"};
	$question = $rqpairs{"question"};
	$answer1 = $rqpairs{"answer1"};
	$answer2 = $rqpairs{"answer2"};
	$answer3 = $rqpairs{"answer3"};
	$answer4 = $rqpairs{"answer4"};
	$subject = $rqpairs{"subject"};
	$choice = $rqpairs{"choice"};

	&HTMLHidden("mode","modify_input");
	
	&HTMLHidden("questno", $questno);
	
	$sqlerror = "<H2> Sorry, that is not a valid question number. </H2><BR>";

     if ($question eq "")
     {
	 # Perform query.
	 $qry = "SELECT question, subject, owner, answer_1, answer_2, answer_3,
	 	 answer_4, correct_number FROM question_pool WHERE q_no = $quoted_questno"; 
	 $cid = $oradb->SQL_OpenQuery($qry) or $sqlerror;
 
	 #if query is successful then find the values of the related attributes
	  if( @a_row = $oradb->SQL_FetchRow($cid) )
	  {
	     $question = $a_row[0];
	     $subject = $a_row[1];
	     $owner = $a_row[2];
	     $answer1 = $a_row[3];
	     $answer2 = $a_row[4];
	     $answer3 = $a_row[5];
	     $answer4 = $a_row[6];
	     $choice = $a_row[7];
  	  }
  
	 $oradb->SQL_CloseQuery ($cid);
	 
	 # Get Picture info.
	 $qry = "SELECT picture_number FROM picture_used WHERE q_no = $quoted_questno"; 
	 $cid = $oradb->SQL_OpenQuery($qry) or $sqlerror;
 
 	 $i=0;
	 #if query is successful then find the values of the related attributes
	  while( @b_row = $oradb->SQL_FetchRow($cid) )
	  {
		$picno[$i] = $b_row[0];
				
		$i++;
  	  }
  
	 $oradb->SQL_CloseQuery ($cid);

	#Be sure that the owner is modifying their question, and not someone else.
	if($username ne $owner)
	{
	  #print "$username $owner";
	  print "<H2> Sorry, you do not own this question and may not change it. </H2><BR>";
	  exit;
	}
	
	$picture1=$picno[0];
	$picture2=$picno[1];
	
      }
	
	
	# Display input fields with current database information.
	print "<br>\n";
	print "Question Pool Number: $questno";
	print "<br>";

	print "<br>\n";
	print "Input the Test Question";
	print "<br>\n";
	&HTMLTextArea("question",$question,60,10);
	print "<br>";
	
	print "Picture 1 Number: ";
	&HTMLInputText("picture1",5,$picture1);
	print " &nbsp;&nbsp;&nbsp;&nbsp;
		<input type=\"submit\" name=\"test\" value=\"Get Picture 1\">";
	print "<br>\n";
	print "Picture 2 Number: ";
	&HTMLInputText("picture2",5,$picture2);
	print " &nbsp;&nbsp;&nbsp;&nbsp;
		<input type=\"submit\" name=\"test\" value=\"Get Picture 2\">";
	print "<BR>\n";

	#choice button allows the user to choose the correct 
	#answer from all the four possible answers

	print "<br>\n";
	print "Input possible answers and choose the button before the correct answer.";
	print "<br>\n";
	
	#Decide the radio button for correct answer.
	if ( $choice eq "A")
	{
	  $Aanswer=1; $Banswer=0; $Canswer=0; $Danswer=0;
	}
	elsif( $choice eq "B")
	{
	  $Aanswer=0; $Banswer=1; $Canswer=0; $Danswer=0;
	}
	elsif( $choice eq "C")
	{
	  $Aanswer=0; $Banswer=0; $Canswer=1; $Danswer=0;
	}
	elsif( $choice eq "D")
	{
	  $Aanswer=0; $Banswer=0; $Canswer=0; $Danswer=1;
	}
	
	#Display answers.
	&HTMLRadioButton("choice","A",$Aanswer," Answer 1 ");	
	&HTMLInputText("answer1",50,$answer1);
	print "<br>\n";
	&HTMLRadioButton("choice","B",$Banswer," Answer 2 ");
	&HTMLInputText("answer2",50,$answer2);
	print "<br>\n";
	&HTMLRadioButton("choice","C",$Canswer," Answer 3 ");
	&HTMLInputText("answer3",50,$answer3);
	print "<br>\n";
	&HTMLRadioButton("choice","D",$Danswer," Answer 4 ");
	&HTMLInputText("answer4",50,$answer4);
	print "<br>\n";


	#Decide the radio button for the section.
	if ( $subject eq "AREA AND VOLUME")
	{
	  $Aanswer=1; $Banswer=0; $Canswer=0;
	}
	elsif( $subject eq "POLYGONS AND THEIR MEASUREMENTS")
	{
	  $Aanswer=0; $Banswer=1; $Canswer=0;
	}
	elsif( $subject eq "TRIG FUNCTIONS")
	{
	  $Aanswer=0; $Banswer=0; $Canswer=1;
	}


	#The subject tag is needed to pull out questions from
	#the question pool in the test.

	print "<br>\n";
	print "Choose the subject this question applies to.";
	print "<br>\n";
	&HTMLRadioButton("subject","AREA AND VOLUME",$Aanswer,"  The Area and Volume Test");
	print "<BR>\n";
	&HTMLRadioButton("subject","POLYGONS AND THEIR MEASUREMENTS",$Banswer,"  The Polygons and Their Measurements Test");
	print "<BR>\n";
	&HTMLRadioButton("subject","TRIG FUNCTIONS",$Canswer,"  The Trig Functions Test");
	
	
	print "<BR><BR>\n";
	print "<input type=\"submit\" name=\"test\" value=\"Submit Question\">";
	print "<br>\n";


 # End the HTML form.
 &HTMLEndForm;
 print "\n";
 
 display_HTML_footer();
}

#---------------------------------------------------------
# This script does the actual insertion of the question into
# the question pool when the question has been modified.
# Otherwise it displays a list of pictures to be selected
# for the question.
#---------------------------------------------------------
if ($mode eq "modify_input")
{
 get_cookies();   
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Connection to database and error handling.
 get_oracle_auth();
 
 $oradb = new UMR::OracleObject;

 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title); 
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 if (is_teacher($username,$password) ne 1)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }


 # Set-up HTML document.
 &HTMLContentType;
 $title="Create Test Question";
 display_HTML_header($title);
 

	# Retrieve info from last routine and quote it for input into database.
	$quoted_username = $oradb->SQL_QuoteString($username);
	$picture1 = $rqpairs{"picture1"};
	$quoted_picture1 = $oradb->SQL_QuoteString($picture1);
	$picture2 = $rqpairs{"picture2"};
	$quoted_picture2 = $oradb->SQL_QuoteString($picture2);
	$questno = $rqpairs{"questno"};
	$quoted_questno = $oradb->SQL_QuoteString($questno);
	$question = $rqpairs{"question"};
	$quoted_question = $oradb->SQL_QuoteString($question);
	$answer1 = $rqpairs{"answer1"};
	$quoted_answer1 = $oradb->SQL_QuoteString($answer1);
	$answer2 = $rqpairs{"answer2"};
	$quoted_answer2 = $oradb->SQL_QuoteString($answer2);
	$answer3 = $rqpairs{"answer3"};
	$quoted_answer3 = $oradb->SQL_QuoteString($answer3);
	$answer4 = $rqpairs{"answer4"};
	$quoted_answer4 = $oradb->SQL_QuoteString($answer4);
	$subject = $rqpairs{"subject"};
	$quoted_subject = $oradb->SQL_QuoteString($subject);
	$choice = $rqpairs{"choice"};
	$quoted_choice = $oradb->SQL_QuoteString($choice);
	$test_choice = $rqpairs{"test"};
 

	$sqlerror = "<H2> Your submission has an error. Please be sure that all 
		fields were filled in on the previous page and one question was selected
		as the correct answer. </H2><BR>\n";
	
	# Update the question.
	if ($test_choice eq "Submit Question") 
	{
  	$qry="update QUESTION_POOL set QUESTION=$quoted_question, ANSWER_1 = $quoted_answer1,
	      ANSWER_2 = $quoted_answer2, ANSWER_3 = $quoted_answer3, ANSWER_4 = $quoted_answer4,
	      CORRECT_NUMBER = $quoted_choice, OWNER=$quoted_username, SUBJECT=$quoted_subject
	      where Q_NO = $quoted_questno";

 	#print "Sent query \"$qry\" to database<BR>\n";

	$cid=$oradb->SQL_OpenQuery($qry) or die "$sqlerror";
 	#$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

 
 	$oradb->SQL_CloseQuery($cid);
	
	#Delete existing pictures and input them again.  This is the easiest way there
	#is to ensure that a question update has the two pictures that the teacher wants. 
	$qry = "DELETE from picture_used where q_no = $questno";
	$oradb->SQL_ExecQuery($qry) or $oradb->SQL_Error && die "$qry";
	
	# Input pictures into picture_used relation. 
 	unless ($picture1 eq "") {
	$qry="insert into PICTURE_USED(PICTURE_NUMBER,Q_NO) values (".
	"$quoted_picture1,$quoted_questno)";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";
 	$oradb->SQL_CloseQuery($cid);
	}
	unless ($picture2 eq "") {
	$qry="insert into PICTURE_USED(PICTURE_NUMBER,Q_NO) values (".
	"$quoted_picture2,$quoted_questno)";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";
 	$oradb->SQL_CloseQuery($cid);
	
	}
	&HTMLStartForm(&HTMLScriptURL);
 	print "\n";
	
	print "Question number $questno was updated.<BR><BR>
	       Please keep this number for your records. <BR> You will need this number if you
	       later wish to edit this question. <BR><BR>";
 	
 	&HTMLSubmit("<-Back");
 	print "\n";
	&HTMLEndForm;
 	print "\n";
	} 

	#### Display picture pool.
	elsif ($test_choice eq "Get Picture 1")
	{
	&HTMLStartForm(&HTMLScriptURL);
	print "\n";
	$qry="SELECT * From PICTURE order by picture_number";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

 		#print "Sent query \"$qry\" to database<BR>\n";
		
		print "<H4>Select the radio button to the picture you would like to appear
			in your test and select the return button at the bottom of the 
			page.</H4><BR><BR>";
		
		while ( @a_row = $oradb->SQL_FetchRow($cid) )
 		{
		&HTMLRadioButton("picture1",$a_row[0],$off,"Picture Number: $a_row[0]");


		##------------------------------------------------------------------
		## To change the location of the picture pool, adjust this path.
		##------------------------------------------------------------------
		print "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
		print "<IMG SRC=http://www.umr.edu/~traxdev/pics/$a_row[1]>";
		print "<BR><BR><BR>\n";
		}
		&HTMLHidden("mode","display_modify");
		print "\n";
		&HTMLHidden("question",$question);
		&HTMLHidden("questno",$questno);
		&HTMLHidden("answer1",$answer1);
		&HTMLHidden("answer2",$answer2);
		&HTMLHidden("answer3",$answer3);
		&HTMLHidden("answer4",$answer4);
		&HTMLHidden("subject",$subject);
		&HTMLHidden("picture2",$picture2);
		&HTMLHidden("choice",$choice);
		print "<BR>\n";
		print "<BR>\n";
		print "<BR>\n";						
		&HTMLSubmit("Select and Return");
 		print "\n";
		&HTMLEndForm;
 		print "\n";
	}
	elsif ($test_choice eq "Get Picture 2")
	{
	&HTMLStartForm(&HTMLScriptURL);
	print "\n";
	$qry="SELECT * From PICTURE order by picture_number";
	print "Sent query \"$qry\" to database<BR>\n";
	$cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";

		print "<H4>Select the radio button to the picture you would like to appear
			in your test and click the return button at the bottom of the 
			page.</H4><BR><BR>";

 	
	while ( @a_row = $oradb->SQL_FetchRow($cid) )
 	{
		&HTMLRadioButton("picture2",$a_row[0],$off,"Picture Number: $a_row[0]");


		##------------------------------------------------------------------
		## To change the location of the picture pool, adjust this path.
		##------------------------------------------------------------------
		print "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
		print "<IMG SRC=http://www.umr.edu/~traxdev/pics/$a_row[1]>";
		print "<BR><BR><BR>\n";
	}
		&HTMLHidden("mode","display_modify");
		print "\n";
		&HTMLHidden("question",$question);
		&HTMLHidden("questno",$questno);
		&HTMLHidden("answer1",$answer1);
		&HTMLHidden("answer2",$answer2);
		&HTMLHidden("answer3",$answer3);
		&HTMLHidden("answer4",$answer4);
		&HTMLHidden("subject",$subject);
		&HTMLHidden("picture1",$picture1);
		&HTMLHidden("choice",$choice);
		print "<BR>\n";
		print "<BR>\n";
		print "<BR>\n";						
		&HTMLSubmit("Select and Return");
 		print "\n";
		&HTMLEndForm;
 		print "\n";
 		}

 # End the HTML form.
 
 display_HTML_footer();	

 }
