#!/umr/bin/perl

# Written by:	Mike Krasche
# Last updated:	5/14/01
# Description:	This script allows a teacher or a student to change
#		his/her password.  The user_id and current password are
#		read from the cookie and the new password is input twice
#		to verify the change.
# Inputs:	User_id and current password from the cookie.
# Outputs:	Writes new password out to the database.

use lib "/afs/umr.edu/software/umrperl/libs";
use UMR::OracleObject;
use UMR::HTMLUtil;

# Requires this file which contains a library of functions.
require "geometry_funcs.pl";

$title="Change Password Page";

&HTMLGetRequest;

$mode=$rqpairs{"mode"};

# Main function to get input of new password and verify user credentials.
unless ($mode)
{
  # Page Header/Title for web
  &HTMLContentType;
  display_HTML_header($title);
  print "<H3>$title</H3>\n";

  # Get current user name and password from the cookie.
  get_cookies();
  $username=$cookies{"geometry_username"};
  $password=$cookies{"geometry_password"};

  # Establish connection with Oracle database.
  get_oracle_auth();
  $oradb = new UMR::OracleObject;
  unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
  {
    $oradb->SQL_Error ("Can't open database");
    display_HTML_footer();
    exit;
  }

  # Call function in geometry_funcs.pl to determine if the user is a
  # teacher or a student.
  $is_student=is_student($username,$password);
  $is_teacher=is_teacher($username,$password);

  # If not a teacher or student.
  unless ($is_student || $is_teacher)
  {
    print "Error: Unable to verify login credentials.<BR>\n";
    display_HTML_footer();
    exit;
  }

  &HTMLStartForm(&HTMLScriptURL);
  print "\n";
  &HTMLHidden("mode","query");

  # Hide values to be passed to the next subroutine.
  &HTMLHidden("username",$username);
  &HTMLHidden("password",$password);

  # Display username and have user enter new password twice.
  print "Username: $username<BR>\n";
  print "Enter New Password: ";
  &HTMLInputPassword("newpass",25,"");
  print "<BR>\n";
  print "ReEnter New Password: ";
  &HTMLInputPassword("newpass2",25,"");
  print "<BR><BR>\n";
  &HTMLSubmit("Execute");
  &HTMLEndForm;
  print "\n";
  display_HTML_footer();
}

# Second part which changes the password or rejects the change.
if( $mode eq "query" )
{
 get_cookies();
 $username=$cookies{"geometry_username"};
 $password=$cookies{"geometry_password"};

 # Establish connection with Oracle database.
 get_oracle_auth();
 $oradb = new UMR::OracleObject;
 unless ($oradb->SQL_OpenDatabase ($tnsname, %orainfo))
 {
  &HTMLContentType;
  display_HTML_header($title);
  $oradb->SQL_Error ("Can't open database");
  display_HTML_footer();
  exit;
 }

 # Verify credentials.
 $is_student=is_student($username,$password);
 $is_teacher=is_teacher($username,$password);
 unless ($is_student || $is_teacher)
 {
  &HTMLContentType;
  display_HTML_header($title);
  print "Invalid login.<BR>\n";
  display_HTML_footer();
  exit;
 }

  # Retrieve data passed from last subroutine.
  $newpass = $rqpairs{"newpass"};
  chomp($newpass);
  $newpass2 = $rqpairs{"newpass2"};
  chomp($newpass2);


  # Run query with database to get current password.
  $quoted_username = $oradb->SQL_QuoteString($username);
  if ($is_teacher eq 1)
  {
    $qry="select PASSWORD from TEACHER where user_id=$quoted_username";
  }
  if ($is_student eq 1)
  {
    $qry="select PASSWORD from STUDENT where user_id=$quoted_username";
  }

  $cid=$oradb->SQL_OpenQuery($qry);

  # Left for testing purposes.
  # $cid=$oradb->SQL_OpenQuery($qry) or $oradb->SQL_Error && die "query failed";
  # print "Sent query \"$qry\" to database\n";

  # Get data from query if it exists
  if( @a_row = $oradb->SQL_FetchRow($cid) )
  { 
   # Grab the password from the query
     $curpassword = $a_row[0];
  }
  else
  {
     &HTMLContentType;
     print "User ID not found in database\n";
     $oradb->SQL_CloseQuery($cid);
     exit;
  }  
  $oradb->SQL_CloseQuery($cid);
   
  # Check that cookie password equals database password.
  if( $curpassword eq $password )
  {
   # Check to see if the new passwords are the same.
    if($newpass eq $newpass2)
    {
      #update the password;
       $quoted_newpass = $oradb->SQL_QuoteString($newpass);
       if ($is_teacher eq 1)
       {
         $qry = "update TEACHER set PASSWORD = $quoted_newpass where USER_ID = $quoted_username";
       }
       if ($is_student eq 1)
       {
         $qry = "update STUDENT set PASSWORD = $quoted_newpass where USER_ID = $quoted_username";
       }
       $oradb->SQL_ExecQuery($qry);
       # $oradb->SQL_ExecQuery($qry) or $oradb->SQL_Error && die "query failed";
       set_cookie("geometry_username",$username);
       set_cookie("geometry_password",$newpass);
       &HTMLContentType;
       display_HTML_header($title);
       print "<H3>$title</H3>\n";

       # print "Sent query \"$qry\" to database\n";
       print "Password was successfully changed.\n";
    }
    else
    {
       &HTMLContentType;
       print "Input passwords do not match.\n";
    }   
  }  
  else
  {
     &HTMLContentType;
     print "<b>Invalid Password!</b>\n";
  }   
  display_HTML_footer();
}


