#!/umr/bin/perl
# 
# Author: Adam Dang
# Course: CS 319
# Date: 5 may 2001
# Database Interaction: 
#    Input: Student user id
#    Output: Display exam record based on student user id by the main 
#               body of the script.
#            Reset and display student exam record if selected 
#               (sub reset_lesson) and/or
#            Reset and display student password if selected 
#               (sub reset_password and sub pass_gen).
#            The subroutines will also write and commit changes made to 
#               the database.
#
# Details: A student id will be send to be process/view.  This script 
# will use the student id to pull up the exam record for the student.  
# Once the record is display, the teacher/admin can reset each individual
# test.  The teacher/admin can also reset the student's to a random 
# 6-character password.  Once the data has been pull from the database 
# and updated, the script will commit the data.  once the data is commit, 
# the script will display the new data.
#
# This script require the umr perl library.  Also, another script
# written by ryan lantzer was used to deal with cookies and accessing
# the database.

# UMR perl and oracle library files

use lib "/afs/umr.edu/software/umrperl/libs";
use UMR::HTMLUtil;
use UMR::OracleObject;

# Ryan Lantzer's script to hand cookies
require "geometry_funcs.pl";


# Got from the Perl Monk Forum by Russ
#
# Creates passwords from a customizable list of characters
# (To make it easier on users, don't use zero or capital 'O', for example)
#
# *Not* a completely security-conscious implementation, especially when 
# generating multiple passwords at once...
#
# Change @Chars to suit your preference
# Change the inner for loop to determine password length
# 
# Usage: $0 [Number of passwords to generate]

sub pass_gen
{ 
   my @chars_list = split '',         
      'abcdefghijkmnopqrstuvwxyzABCDEFGHJKMNPQRSTUVWXYZ23456789';
   for (1..($ARGV[0] ||= 1))
   {
      $password_gen;
      for (1..6)
      { 
         $password_gen .= $chars_list[rand @chars_list];
      }
   }
}


$title = "Student Information Page";
$user_id = '1234-028';
$user_id = '1234-004';

# Initialize %rqpairs with submitted variables
&HTMLGetRequest;
&HTMLContentType;

# Check variable "mode" to decide what the script should do
$mode = $rqpairs{"mode"};

# Begin Oracle authenication subroutine
get_oracle_auth();

# Create a new Oracle connection object
$oradb = new UMR::OracleObject;

# Connect to database using USER_ID and PASSWORD from get_oracle_auth()
$oradb->SQL_OpenDatabase($tnsname, %orainfo)||
   $oradb->SQL_Error("Can't open database!!!");

$s_user_id = $oradb->SQL_QuoteString($user_id);

# Will not display student info if a "mode" available
unless ($mode)
{

&HTMLTitle($title);

# Create a query statement
# Eventually, the querry will pass on the student id from the web team

$query_student = "select user_id, fname, lname from student s where s.user_id =
   $s_user_id"; 
   
# Student exam query
$query_exam_record = "select subject, test_status, date_practice, date_test
   from exam_record e where e.s_user_id = $s_user_id";

# Submit a query and return a connection id
$cid = $oradb->SQL_OpenQuery($query_student) or $oradb->SQL_Error("Query
   failed");

# Student info report
# Print header for report
print "<TABLE BORDER = 0> \n";
print "<TR><TD>User ID</TD><TD>First Name</TD><TD>Last Name</TD></TR> \n";

# Return a_row from query
@a_row = $oradb->SQL_FetchRow($cid);

# Print out student info
print "<TR>\n";
$num=@a_row;
for ($i=0;$i<$num;$i++)
{
   print "<TD>";
   print $a_row[$i];
   print "</TD>\n";
}
print "</TR>\n";
#print "<BR>\n";
print "</TABLE> \n";

# Close query connection
$oradb->SQL_CloseQuery($cid);

print "<BR>";

# Submit a query and return a connection id
$cid_exam = $oradb->SQL_OpenQuery($query_exam_record) or 
   $oradb->SQL_Error("Query failed");

# Exam record report
# Print header for exam report
print "<TABLE BORDER = 0>";
print "<TR><TD></TD>";
print "<TD>Subject</TD><TD>Test Status</TD><TD>Date Practice</TD>";
print "<TD>Date Test<TD></TR>";

# While loop to print out all result from query
$j=0;


#######################################
&HTMLStartForm(&HTMLScriptURL);
#######################################

while(@a_row = $oradb->SQL_FetchRow($cid_exam))
{
   $subject[$j] = $a_row[0];
   
   # Print out student exam info
   print "<TR><TD>";
   
   # Default button selection
   $k = 0;
   if ($j eq 0)
   {
      $k = 1;
   }
   
   &HTMLRadioButton("mode", $subject[$j], $k);
   
   # Increment subject counter
   $j++;
   
   print "</TD>";
   $num=@a_row;
   
   for ($i=0;$i<$num;$i++)
   {
      print "<TD>";
      print $a_row[$i];
      print "</TD>\n";
   }
   print "</TR>\n";
#   print "<BR>\n";
}
print "</TABLE> \n";

# Close query connection
$oradb->SQL_CloseQuery($cid_exam);

print "<BR>";

# Reset and display lesson
&HTMLSubmit("Reset Lesson");

&HTMLEndForm;

&HTMLStartForm(&HTMLScriptURL);

# Reset and display new student password
&HTMLHidden("mode", "reset_password");
&HTMLSubmit("Reset Password");

############################
&HTMLEndForm;
###########################

}

# Which button to execute
if ($mode eq "reset_password")
{
   reset_password();
}

if ($mode and !($mode eq "reset_password"))
{
   print "Test Reset <BR>";
   reset_lesson();
}


# Reset lesson subroutine
sub reset_lesson
{
   # Create Oracle safe
   my $new_mode = $oradb->SQL_QuoteString($mode);
   
   # Reset lesson
   $query_reset_lesson = "update exam_record set date_test = NULL, test_status =
   'Not Taken' where s_user_id = $s_user_id and subject = $new_mode";
      
   # Open query connection
   $cid_reset_lesson = $oradb->SQL_OpenQuery($query_reset_lesson) or 
      $oradb->SQL_Error("Query failed");
      
   # Close query connection
   $oradb->SQL_CloseQuery($cid_reset_lesson);
      
   # Display updated lesson
   $cid_reset_lesson = $oradb->SQL_OpenQuery("select subject, test_status, 
      date_practice, date_test from exam_record e 
      where e.s_user_id = $s_user_id and e.subject = $new_mode") 
      or $oradb->SQL_Error("Query failed");

   # Exam record report
   # Print header for exam report
   print "<TABLE BORDER = 0>";
   print "<TR>";
   print "<TD>Subject</TD><TD>Test Status</TD><TD>Date Practice</TD>";
   print "<TD>Date Test<TD></TR>";

   @a_row = $oradb->SQL_FetchRow($cid_reset_lesson);

   $num=@a_row;
   print "<TR>";
   for ($i=0;$i<$num;$i++)
   {
      print "<TD>";
      print $a_row[$i];
      print "</TD>\n";
   }
   print "</TR>\n";
   
   print "</TABLE> \n";      

}





# Reset password subroutine
sub reset_password
{
   pass_gen();
   # Create Oracle safe
   my $new_password_gen = $oradb->SQL_QuoteString($password_gen);
   
   # Reset student password query
   $query_reset_password = "update student set password = $new_password_gen 
      where user_id = $s_user_id";

   # Open query connection for print out of old password
   $cid_reset_password = $oradb->SQL_OpenQuery("select password from student
      where user_id = $s_user_id") or $oradb->SQL_Error("Query failed");
   
   @a_row = $oradb->SQL_FetchRow($cid_reset_password);
   
   # Print out old password
   print "This is the old password:  ";
   print $a_row[0];
   print "<BR>";

   # Close querry connection
   $oradb->SQL_CloseQuery($cid_reset_password);

   # Open new query connection for query_reset_password
   $cid_reset_password = $oradb->SQL_OpenQuery($query_reset_password) or
      $oradb->SQL_Error("Query failed");
      
   # Close query connection
   $oradb->SQL_CloseQuery($cid_reset_password);
   
   # Open query connection for print out of new password
   $cid_reset_password = $oradb->SQL_OpenQuery("select password from student
      where user_id = $s_user_id") or $oradb->SQL_Error("Query failed");
   
   @a_row = $oradb->SQL_FetchRow($cid_reset_password);
      
   # Print out new password
   print "This is the new password:  ";
   print $a_row[0];
   print "<BR>";

   # Close query connection
   $oradb->SQL_CloseQuery($cid_reset_password);

}






 
   
   
   
   
